// oolite.oxp.Layne.DockingFees
"use strict";

this.name = "Docking Fees";
this.version = "1.6";
this.licence = "CC BY-NC-SA 4.0";

this._simulator = false; // holding variable to work out whether this launch/dock routine was part of a simulator run

this.shipDockedWithStation = function (station) {
    // if this was a simulator run, reset the variable and return - no docking fee in this case
    if (this._simulator == true) {
        this._simulator = false;
        return;
    }
    // is this a redock after an escape pod
    if ((global.clock.adjustedSeconds - global.clock.seconds) > 1300) return;
	
    // work out fee based on system tech level and station type
    var f = ((system.techLevel * 0.5) + 0.5);
    var fee = 0;
    var dock_mess = ""; //no message by default

    if ( station.isMainStation ) { // main system stations for GalCop
        fee = f;
        // make sure the "dock_mess" value is the same as what you used in the descriptions.plist file
        dock_mess = system.techLevel;
    }
    if (station.hasRole("rockhermit")) {fee = 0; dock_mess = "rock";} // rockhermits are free, must be before astromine
    if (station.hasRole("sfep_station")) {fee = f*0.5; dock_mess = system.techLevel;} // stations for extra planets are cheaper to visit than main station
    if (station.hasRole("constore")) {fee = 0; dock_mess = "store";} // con stores are free for encouraging customers
    if (station.hasRole("smivs_pizza_giftshop")) {fee = 0; dock_mess = "";} // space-pizza charges a fee of its own, so no dock message
    if (station.hasRole("oolite-tutorial-station")) {fee = 0; dock_mess = "";} // the training station in the tutorial; no fee or message
    if (station.hasRole("rrs-plague-mine")) {fee = 0; dock_mess = "";} // plague mine, free docking for medical couriers
	if (station.hasRole("random_hits_any_spacebar")) {fee = f*1.5; dock_mess = "spacebar";} // space bars are a little bit more expensive
    if (station.hasRole("rrs_group_spacestation")) {fee = 0; dock_mess = "RRS";} // rescue stations are free
    if (station.hasRole("casinoship")) {fee = f*2; dock_mess = "hoopy";} // casinos are a bit more expensive
    if (station.hasRole("wildShips_kiota")) {fee = f*1.3; dock_mess = "kiota";} // kiota ships are a little bit more expensive
    if (station.hasRole("rrs-mining-outpost")) {fee = 0; dock_mess = "mining";} // mining outposts are free
    if (station.hasRole("free_trade_zone")) {fee = 0; dock_mess = "FTZ";} // free trade zones charge huge fuel prices in lieu of fee
    if (station.hasRole("astromine")) {fee = 20; dock_mess = "astromine";} // penal colonies require a fair bribe to enter
    if (station.hasRole("comczgf")) {fee = f*2.5; dock_mess = "ZGF";} // Zero-G-Factories require a small bribe to enter
    if (station.hasRole("comslapu")) {fee = f*2.5; dock_mess = "SLAPU";} // SLAPU collectives require a small bribe to enter
    if (station.hasRole("astrofactory")) {fee = f*2; dock_mess = "astrofactory";} // imperial factories require a small bribe to enter
    if (station.hasRole("laveAcademy_academy")) {fee = 0; dock_mess = "laveacademy";} // Lave Academy is free as a public service
    if (station.hasRole("anarchies_sentinel_station")) {fee = 0; dock_mess = "secom";} // Sentinel Stations are free naval bases
    if (station.hasRole("anarchies_renegade_station")) {fee = 0; dock_mess = "";} // renegade stations have their own penalties for docking
	if (station.hasRole("anarchies_hacker_outpost")) {fee = 0; dock_mess = "hackers";} // if you can find them, hacker outposts are free
    if (station.hasRole("anarchies_salvage_gang")) {fee = f*2; dock_mess = "salvager";} // salvage gangs need a bribe to grease the wheels
    if (station.hasRole("navystat")) {fee = 0; dock_mess = "secom";} // navy stations are free (your tax dollars at work)
    if (station.hasRole("behemoth")) {fee = 0; dock_mess = "behemoth";} // behemoths are free
    if (station.hasRole("liners_liner")) {fee = 0; dock_mess = "liner";} // passenger liners are free
    if (station.hasRole("feudal-hunting-lodge")) {fee = 0; dock_mess = "hunting";} // royal lodges are free
    if (station.hasRole("planetFall_surface")) {fee = f*1.2; dock_mess = "planet";} // planets are slightly more to discourage spacers
    if (station.hasRole("monkbranch")) {fee = 0; dock_mess = "monks";} // black monk monasteries are free
    if (station.hasRole("taxi_station")) {fee = f*0.5; dock_mess = "taxi";} // taxi stations just charge for the parking
    if (station.hasRole("aquatics_HQ")) {fee = 0; dock_mess = "aquatica";} //Aquatics Shipyards are free to dock with
    if (station.hasRole("GRS-Station")) {fee = 0; dock_mess = "buoystat";} //BuoyRepair HQ is free to dock with
    if (station.hasRole("pagroove_superhub")) {fee = f*2; dock_mess = "suphub";} //Superhubs are expensive to dock with
    if (station.hasRole("toriA")) {fee = f*1.2; dock_mess = system.techLevel;} //Torus station cost more than standard GalCop stations
    if (station.hasRole("toriB")) {fee = f*1.2; dock_mess = system.techLevel;} //Torus station cost more than standard GalCop stations
    if (station.hasRole("dredgers")) {fee = 0; dock_mess = "dredgj";} //Deep Space Dredger are free to dock with, if you can find one
    if (station.hasRole("globestation")) {fee = f*1.5; dock_mess = system.techLevel;} //Globe stations are more expensive to dock with
    if (station.hasRole("globestationxl")) {fee = f*1.5; dock_mess = system.techLevel;} //Globe stations are more expensive to dock with
    
	if (station.hasRole("baakili-fartrader")) {fee = f*0.5; dock_mess = "short";} //Baakili Far Trader
    if (station.hasRole("bh01")) {fee = f*0.5; dock_mess = "short";} //Bulk Haulers
    if (station.hasRole("broadcast_array")) {fee = 0; dock_mess = "";} //Tionisla Chronicle Array
    if (station.hasRole("cb68_sodalite_station-riredi-coluber")) {fee = f; dock_mess = "short";} //Riredi
    if (station.hasRole("draven_c")) {fee = f; dock_mess = "short";} //Draven Carrier
    if (station.hasRole("draven_st")) {fee = f; dock_mess = "short";} //Draven Oodulldoff Station
    if (station.hasRole("habmk2")) {fee = f; dock_mess = "short";} //Zieman's Habitat Station
    if (station.hasRole("kihq")) {fee = f; dock_mess = "short";} //Koneko Industries OXP
    if (station.hasRole("mandotech-main-station")) {fee = f; dock_mess = "short";} //MandotechStation Shipyard
    if (station.hasRole("medusa")) {fee = f; dock_mess = "short";} //Nuit Space Station OXP
    if (station.hasRole("PAGroove-Orisis")) {fee = f; dock_mess = "short";} //Orisis
    if (station.hasRole("ryan_villa")) {fee = 0; dock_mess = "";} //Ryan's Villa
    if (station.hasRole("SIRF-YARD")) {fee = f; dock_mess = "short";} //S.I.R.F.
    if (station.hasRole("sothis")) {fee = f; dock_mess = "short";} //SothisTC
    if (station.hasRole("taranis")) {fee = f; dock_mess = "short";} //Taranis
    if (station.hasRole("tianve-pulsar-station")) {fee = f; dock_mess = "short";} //Tianve and Navy Station
    if (station.hasRole("transhabstation")) {fee = f; dock_mess = "short";} //Transhab station

    if (fee > 0) {  // ignore any station not specifically assigned a fee or message
        if (player.credits > fee) { // make sure the player has enough credits
            player.credits -= fee;
            player.addMessageToArrivalReport(expandDescription("[dockfee_" + dock_mess+ "]", {fee_amt:fee, st_name:station.displayName}));
        } else {
            player.addMessageToArrivalReport("Welcome Commander! You seem to be down on your luck, so we've waived the docking fee this time.  You can work it off washing dishes in the station commissary!");
        }
    }
    // if there's no fee, but we still have a dock message to deliver, add it now
    if (fee == 0 && dock_mess != "") {
        player.addMessageToArrivalReport(expandDescription("[dockfee_" + dock_mess+ "]", {fee_amt:fee, st_name:station.displayName}));
    }
}
// check when the player launches if this is a simulator run
this.shipLaunchedFromStation = function(station) {
    if (this.$simulatorRunning()) this._simulator = true;
}

// routine to check the combat simulator worldscript, to see if it's running or not
this.$simulatorRunning = function() {
    var w = worldScripts["Combat Simulator"];
    if (w && w.$checkFight && w.$checkFight.isRunning) return true;
    return false;
}